==> haskell-hls-explicit-fixity-plugin-1.1.0.0-132-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-explicit-fixity-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-explicit-fixity-plugin
version:              1.1.0.0
visibility:           public
id:                   hls-explicit-fixity-plugin-1.1.0.0-DkI5qiqLac46kHOetlibB2
key:                  hls-explicit-fixity-plugin-1.1.0.0-DkI5qiqLac46kHOetlibB2
license:              Apache-2.0
maintainer:           julytreee@gmail.com
author:               Lei Zhu
synopsis:             Show fixity explicitly while hovering
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server/tree/master/plugins/hls-explicit-fixity-plugin#readme>

category:             Development
abi:                  caf6f2dbe306305b108e9823a2002973
exposed:              True
exposed-modules:      Ide.Plugin.ExplicitFixity
import-dirs:
    /usr/lib/ghc-9.0.2/site-local/hls-explicit-fixity-plugin-1.1.0.0

library-dirs:
    /usr/lib/ghc-9.0.2/site-local/hls-explicit-fixity-plugin-1.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-explicit-fixity-plugin
hs-libraries:         HShls-explicit-fixity-plugin-1.1.0.0-DkI5qiqLac46kHOetlibB2
depends:
    base-4.15.1.0 containers-0.6.4.1 deepseq-1.4.5.0
    extra-1.7.14-LeGtA61kank1nfrcvwQEPL ghc-9.0.2
    ghcide-1.9.1.0-4v981bncGfv7lGvePtfxX
    hashable-1.4.3.0-LTYvL1TeA7ZGWACRCRhioS
    hls-plugin-api-1.6.0.0-EoAGZxnzRUr7h0wQJlGdxB
    lsp-1.6.0.0-4RlMBMQeaME3rXSRggJdLR text-1.2.5.0
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-explicit-fixity-plugin/html/hls-explicit-fixity-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-explicit-fixity-plugin/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-explicit-fixity-plugin-1.1.0.0-146-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-explicit-fixity-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-explicit-fixity-plugin
version:              1.1.0.0
visibility:           public
id:                   hls-explicit-fixity-plugin-1.1.0.0-y9vFMSjBWk59zEVxaLkuP
key:                  hls-explicit-fixity-plugin-1.1.0.0-y9vFMSjBWk59zEVxaLkuP
license:              Apache-2.0
maintainer:           julytreee@gmail.com
author:               Lei Zhu
synopsis:             Show fixity explicitly while hovering
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server/tree/master/plugins/hls-explicit-fixity-plugin#readme>

category:             Development
abi:                  9d295fb7c64c8115471d844aeb795559
exposed:              True
exposed-modules:      Ide.Plugin.ExplicitFixity
import-dirs:
    /usr/lib/ghc-9.0.2/site-local/hls-explicit-fixity-plugin-1.1.0.0

library-dirs:
    /usr/lib/ghc-9.0.2/site-local/hls-explicit-fixity-plugin-1.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-explicit-fixity-plugin
hs-libraries:         HShls-explicit-fixity-plugin-1.1.0.0-y9vFMSjBWk59zEVxaLkuP
depends:
    base-4.15.1.0 containers-0.6.4.1 deepseq-1.4.5.0
    extra-1.7.14-DtzIfRYPdKwKG7ww90MJHk ghc-9.0.2
    ghcide-1.9.1.0-6LjNtXxEsFjP6FTRfnjBs
    hashable-1.4.3.0-JNIl3QAmQdVCUYfpxV7wfJ
    hls-plugin-api-1.6.0.0-AMyEr3ncypu50jLRT7GrE2
    lsp-1.6.0.0-A16Z9QgFStqCp41XDJvaIy text-1.2.5.0
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-explicit-fixity-plugin/html/hls-explicit-fixity-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-explicit-fixity-plugin/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
